==> WebSocketCommandline-0.0.7.tar.gz: WebSocketCommandline-0.0.7/setup.py <==
"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

long_description='WebSocketCommandline is a command line tool to easily test the connectivity of WebSocket client/server in shell with Python.'

try:
    import pypandoc
    long_description = pypandoc.convert('README.md', 'rst')
except (IOError, ImportError):
    pass

setup(
    name='WebSocketCommandline',
    packages=['WebSocketCommandline'],

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='0.0.7',

    # The project's main homepage.
    url='https://github.com/owwlo/WebSocketCommandline',
    download_url = 'https://github.com/owwlo/WebSocketCommandline/tarball/0.0.7',

    description='A Python script to test WebSocket.',
    long_description=long_description,

    # Author details
    author='owwlo',
    author_email='owwlo.g@gmail.com',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    # What does your project relate to?
    keywords='websocket test server client development',

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    py_modules=["WebSocketCommandline"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[
        'autobahn>=0.14.1',
        'Twisted>=16.2.0',
        'PyTerminalCommander>=0.0.4'
    ],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'websocket_tester=WebSocketCommandline:main'
        ],
    },
)

==> WebSocketCommandline-0.0.8.tar.gz: WebSocketCommandline-0.0.8/setup.py <==
"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

long_description='WebSocketCommandline is a command line tool to easily test the connectivity of WebSocket client/server in shell with Python.'

try:
    import pypandoc
    long_description = pypandoc.convert('README.md', 'rst')
except (IOError, ImportError):
    pass

VERSION = "0.0.8"

setup(
    name='WebSocketCommandline',
    packages=['WebSocketCommandline'],

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version=VERSION,

    # The project's main homepage.
    url='https://github.com/owwlo/WebSocketCommandline',
    download_url = 'https://github.com/owwlo/WebSocketCommandline/tarball/{}'.format(VERSION),

    description='A Python script to test WebSocket.',
    long_description=long_description,

    # Author details
    author='owwlo',
    author_email='owwlo.g@gmail.com',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    # What does your project relate to?
    keywords='websocket test server client development',

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    py_modules=["WebSocketCommandline"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[
        'autobahn>=0.14.1',
        'Twisted>=16.2.0',
        'PyTerminalCommander>=0.0.4'
    ],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'websocket_tester=WebSocketCommandline:main'
        ],
    },
)
